#  μετάμάσκα - malevolent payload classifier
meta.mask can detect different types of malicious payloads like SQL injection, XSS, path-traversal, and command injection payloads.

[![pypi](https://img.shields.io/pypi/v/metamaska.svg)](https://pypi.org/project/metamaska/)
[![python](https://img.shields.io/pypi/pyversions/metamaska.svg)](https://pypi.org/project/metamaska/)
[![Build Status](https://github.com/happyhackingspace/metamaska/actions/workflows/ci.yml/badge.svg)](https://github.com/happyhackingspace/metamaska/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/happyhackingspace/metamaska/branch/main/graphs/badge.svg)](https://codecov.io/github/happyhackingspace/metamaska)



* Documentation: <https://happyhackingspace.github.io/metamaska>
* GitHub: <https://github.com/happyhackingspace/metamaska>
* PyPI: <https://pypi.org/project/metamaska/>
* Free software: MIT


## TODO

* support more types
* support interoperable model formats, more at [here](https://scikit-learn.org/stable/model_persistence.html#interoperable-formats)

## Credits

- [Cookiecutter](https://github.com/audreyr/cookiecutter)
- [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage)
- [ML-based-WAF](https://github.com/vladan-stojnic/ML-based-WAF)
- [WAF-A-MoLE](https://github.com/AvalZ/WAF-A-MoLE)
